@@ -1,6 +1,7 @@
 import argparse
 from replbuilder import ReplCommand
 from time import strftime, localtime
+from .votes import get_vote_stamp
 import html
 
 
@@ -21,8 +22,10 @@ def get_story_parser():
     return parser
 
 
-def print_story(story):
+def print_story(story, vote=None):
     print("\033[1;36m{}\033[0m".format(story["title"]))
+    if vote:
+        print(get_vote_stamp(vote))
     print(strftime('%Y-%m-%d %H:%M:%S', localtime(story["time"])))
     print("AUTHOR: {}".format(story["by"]))
     if "url" in story:
@@ -41,10 +44,13 @@ def get_story(args, context):
         raise ValueError("Must either provide --pointer or --story-id")
     context.store_item(story_id)
     story = context.loaded_items[story_id]
+    vote = None
+    if story_id in context.stored_votes:
+        vote = context.stored_votes[story_id]
     if story["type"] != "story":
         raise ValueError("Provided pointer or id is not a story")
     context.store_link("item?id={}".format(story_id))
-    print_story(story)
+    print_story(story, vote)
 
 
 get_story_command = ReplCommand("get_story", get_story_parser(), get_story, "Get story by pointer shown, use get_comments instead if you also want to see comments", use_context=True)
